@@ -2,29 +2,73 @@ use std::error::Error;
 use std::fs;
 use std::path::{Path, PathBuf};
 
-use question::{Answer, Question};
+use console::style;
+use dialoguer::{Confirm, MultiSelect};
 
 use crate::cli::InstallSubcommandArgs;
 use crate::structs::Dotfile;
-use crate::utils::{clone_repo, get_manifest, get_repo_host_ssh_url, run_command_vec};
+use crate::utils::{clone_repo, get_manifest, get_repo_host_ssh_url, get_theme, run_command_vec};
 use crate::REPO_DIR;
 
 pub fn install_subcommand_handler(args: InstallSubcommandArgs) -> Result<(), Box<dyn Error>> {
     let url = get_repo_host_ssh_url(&args.source)?.to_string() + &args.repository;
+    let theme = get_theme();
 
     clone_repo(Path::new(REPO_DIR), &url)?;
 
     let manifest = get_manifest()?;
 
-    let dotfiles_iter = manifest.into_iter();
-    let dotfiles: Vec<(String, Dotfile)> = if !args.target_dotfiles.is_empty() {
-        dotfiles_iter
+    let dotfiles: Vec<(String, Dotfile)> = if args.all {
+        manifest.into_iter().collect()
+    } else if !args.target_dotfiles.is_empty() {
+        manifest
+            .into_iter()
             .filter(|(dotfile_name, _)| args.target_dotfiles.contains(dotfile_name))
             .collect()
     } else {
-        dotfiles_iter.collect()
+        let dotfile_names = manifest
+            .clone()
+            .into_iter()
+            .map(|pair| pair.0)
+            .collect::<Vec<String>>();
+        let selected = MultiSelect::with_theme(&theme)
+            .with_prompt("Select the dotfiles you wish to install. Use \"SPACE\" to select and \"ENTER\" to proceed.")
+            .items(&dotfile_names)
+            .interact()
+            .unwrap();
+
+        manifest
+            .into_iter()
+            .enumerate()
+            .filter(|(index, (_, _))| selected.contains(index))
+            .map(|(_, (name, dotfile))| (name, dotfile))
+            .collect()
     };
 
+    if dotfiles
+        .iter()
+        .any(|(_, dotfile)| dotfile.pre_install.is_some() || dotfile.post_install.is_some())
+    {
+        println!(
+            "{}",
+            style(
+                "! This manifest contains pre_install and/or post_install \
+                steps, are you sure you trust this manifest?"
+            )
+            .yellow()
+        );
+        let trust = Confirm::with_theme(&theme)
+            .with_prompt("Trust this manifest?")
+            .default(false)
+            .wait_for_newline(true)
+            .interact()
+            .unwrap();
+
+        if !trust {
+            return Err("Aborting due to untrusted dotfile manifest".into());
+        }
+    }
+
     for (dotfile_name, dotfile) in dotfiles {
         let mut origin_path_buf = PathBuf::from(REPO_DIR);
         origin_path_buf.push(&dotfile.file);
@@ -39,17 +83,15 @@ pub fn install_subcommand_handler(args: InstallSubcommandArgs) -> Result<(), Box
         let target_path = Path::new(target_path_str.as_ref());
 
         if target_path.exists() && !args.force {
-            let force = Question::new(
-                format!(
+            let force = Confirm::with_theme(&theme)
+                .with_prompt(format!(
                     "Dotfile \"{}\" already exists on disk. Overwrite?",
                     dotfile_name
-                )
-                .as_str(),
-            )
-            .default(Answer::NO)
-            .show_defaults()
-            .confirm();
-            if force == Answer::NO {
+                ))
+                .default(false)
+                .interact()
+                .unwrap();
+            if !force {
                 continue;
             }
         }
